Documentation
¶
Overview ¶
Package build provides build coordination for remote iOS builds via GitHub Actions. It handles triggering workflows, monitoring progress, and downloading artifacts.
Index ¶
- Constants
- type BuildOptions
- type BuildResult
- type Coordinator
- type Phase
- type PhaseInfo
- type Progress
- func (p *Progress) Complete(phase Phase, message string)
- func (p *Progress) Error(phase Phase, err error)
- func (p *Progress) Finish()
- func (p *Progress) SetWorkflowURL(url string)
- func (p *Progress) Start(buildID string)
- func (p *Progress) Update(phase Phase, message string)
- func (p *Progress) UpdateDownloadProgress(downloaded, total int64)
Constants ¶
const ( // DefaultTimeout is the default build timeout DefaultTimeout = 30 * time.Minute // WorkflowFile is the name of the workflow file WorkflowFile = "ios-build.yml" // IPAArtifactName is the name of the IPA artifact uploaded by the workflow IPAArtifactName = "ipa" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildOptions ¶
type BuildOptions struct {
OutputDir string
Timeout time.Duration
Unsigned bool // Skip code signing even if configured
}
BuildOptions contains options for a build
type BuildResult ¶
type BuildResult struct {
BuildID string
IPAPath string
Duration time.Duration
WorkflowURL string
IPASize int64
}
BuildResult contains the result of a build
type Coordinator ¶
type Coordinator struct {
// contains filtered or unexported fields
}
Coordinator orchestrates the build process
func NewCoordinator ¶
func NewCoordinator(cfg *config.Config, gh *github.Client) *Coordinator
NewCoordinator creates a new build coordinator
func (*Coordinator) Build ¶
func (c *Coordinator) Build(ctx context.Context, opts BuildOptions) (*BuildResult, error)
Build triggers a remote build and downloads the IPA artifact
type Progress ¶
type Progress struct {
// contains filtered or unexported fields
}
Progress tracks and displays build progress
func NewProgress ¶
NewProgress creates a new progress reporter
func (*Progress) SetWorkflowURL ¶
SetWorkflowURL sets the workflow URL for error messages
func (*Progress) UpdateDownloadProgress ¶
UpdateDownloadProgress updates the download progress display
Click to show internal directories.
Click to hide internal directories.